package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.maintain.copier.ShareCopier;
import com.chelvc.cloud.maintain.vo.ShareVO;
import com.chelvc.cloud.vehicle.api.dto.ShareDTO;
import com.chelvc.cloud.vehicle.api.param.SharePagingParam;
import com.chelvc.cloud.vehicle.api.service.ShareService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 分享记录接口
 *
 * @author xp
 * @data 2023/4/5
 */
@Validated
@RestController
@ResponseWrapping
public class ShareController {
    
    @DubboReference
    private ShareService shareService;

    /**
     * 新增分享记录
     *
     * @return 询价主键
     */
    @PostMapping("/share")
    public Long addEnquire() {
        return this.shareService.addShare();
    }


    /**
     * 查询分享记录分页
     *
     * @param param 查询参数
     * @return 分享记录分页信息
     */
    @GetMapping("/share")
    public Pagination<ShareVO> getSharePaging(@Valid SharePagingParam param) {
        Pagination<ShareDTO> sharePaging = this.shareService.getSharePaging(param);
        List<ShareVO> shares = sharePaging.getRecords().stream().map(this::covert).collect(Collectors.toList());
        return sharePaging.convert(shares);
    }

    /**
     * 转换
     *
     * @param share
     * @return
     */
    public ShareVO covert(ShareDTO share) {
        return ShareCopier.INSTANCE.copying(share);
    }
    
}
